/**
 *
 * Copyright 2020 Tencent
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
import { Plugin, PluginServiceApi } from '@cloudbase/framework-core';
/**
 * 导出接口用于生成 JSON Schema 来进行智能提示
 */
export interface IFrameworkPluginDatabaseInputs {
    /**
     * 数据库集合信息，数组类型
     */
    collections: ICollectionInputs[];
}
export interface ICollectionInputs {
    /**
     * 集合名称
     *
     * @maxLength 64
     * @minLength 1
     */
    collectionName: string;
    /**
     * 描述信息
     *
     * @maxLength 128
     * @minLength 1
     */
    description?: string;
    /**
     * 创建的索引
     */
    createIndexes?: ICreateIndex[];
    /**
     * 删除的索引
     */
    DropIndexes?: IDropIndex[];
    /**
     * 权限标签。包含以下取值： READONLY：所有用户可读，仅创建者和管理员可写 PRIVATE：仅创建者及管理员可读写 ADMINWRITE：所有用户可读，仅管理员可写 ADMINONLY：仅管理员可读写 CUSTOM：自定义安全规则
     */
    aclTag?: 'READONLY' | 'PRIVATE' | 'ADMINWRITE' | 'ADMINONLY' | 'CUSTOM';
    /**
     * aclTag 为 CUSTOM 时，安全规则内容
     */
    aclRule?: string;
}
export interface ICreateIndex {
    /**
     * 索引名称
     * @maxLength 64
     * @minLength 1
     */
    name: string;
    /**
     * 是否唯一索引
     */
    unique: boolean;
    /**
     * 描述信息
     */
    keys: IIndexKey[];
}
export interface IDropIndex {
    /**
     * 索引名称
     */
    name: string;
}
export interface IIndexKey {
    /**
     * 字段
     * @maxLength 64
     * @minLength 1
     */
    name: string;
    /**
     * 字段排序，可枚举值：-1（降序）、1（升序）、2dsphere（地理位置）
     */
    direction: '-1' | '1' | '2dsphere';
}
declare class DatabasePlugin extends Plugin {
    name: string;
    api: PluginServiceApi;
    inputs: IFrameworkPluginDatabaseInputs;
    protected resolvedInputs: IFrameworkPluginDatabaseInputs;
    protected buildOutput: any;
    constructor(name: string, api: PluginServiceApi, inputs: IFrameworkPluginDatabaseInputs);
    /**
     * 初始化
     */
    init(): Promise<void>;
    /**
     * 执行本地命令
     */
    run(): Promise<void>;
    /**
     * 删除资源
     */
    remove(): Promise<void>;
    /**
     * 生成代码
     */
    genCode(): Promise<void>;
    /**
     * 构建
     */
    build(): Promise<void>;
    /**
     * 生成SAM文件
     */
    compile(): Promise<{
        Resources: Record<string, any>;
    }>;
    /**
     * 部署
     */
    deploy(): Promise<void>;
    toSAM(collectionConfig: ICollectionInputs): {
        Type: string;
        Properties: any;
    };
    toConstantCase(name: string): string;
}
export declare const plugin: typeof DatabasePlugin;
export {};
//# sourceMappingURL=index.d.ts.map